summaryrefslogtreecommitdiffstats
path: root/qmake
diff options
context:
space:
mode:
authorFrans Englich <frans.englich@nokia.com>2009-10-21 10:07:46 (GMT)
committerFrans Englich <frans.englich@nokia.com>2009-10-21 10:07:46 (GMT)
commit895046d54eee97d838dea1fdcb34a7dff3d91f98 (patch)
tree80bef9bd8cd2d11e448e31aa8d2f69ade312eff5 /qmake
parentf4a10959e579f6c8d77defa24107a5f6a02749b9 (diff)
downloadQt-895046d54eee97d838dea1fdcb34a7dff3d91f98.zip
Qt-895046d54eee97d838dea1fdcb34a7dff3d91f98.tar.gz
Qt-895046d54eee97d838dea1fdcb34a7dff3d91f98.tar.bz2
Revert "Switch from *-armv5 to *-armv6."
This reverts commit a6af1538ea53408399fb29870a4ef16a92c7893a. armv6 is not supported by public SDKs, due to armv6/urel not existing. Such SDKs needs to be fixed by copying the armv5 files. Hence we revert, and postpone until we have SDKs which actually support armv6, and until we have a stronger insight into what advantages armv6 brings.
Diffstat (limited to 'qmake')
-rw-r--r--qmake/generators/symbian/symmake_abld.cpp6
-rw-r--r--qmake/generators/symbian/symmake_sbsv2.cpp6
2 files changed, 6 insertions, 6 deletions
diff --git a/qmake/generators/symbian/symmake_abld.cpp b/qmake/generators/symbian/symmake_abld.cpp
index 692ead7..4d1673b 100644
--- a/qmake/generators/symbian/symmake_abld.cpp
+++ b/qmake/generators/symbian/symmake_abld.cpp
@@ -224,8 +224,8 @@ void SymbianAbldMakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, bool
t << "first: default" << endl;
if (debugPlatforms.contains("winscw"))
t << "default: debug-winscw";
- else if (debugPlatforms.contains("armv6"))
- t << "default: debug-armv6";
+ else if (debugPlatforms.contains("armv5"))
+ t << "default: debug-armv5";
else if (debugPlatforms.size())
t << "default: debug-" << debugPlatforms.first();
else
@@ -259,7 +259,7 @@ void SymbianAbldMakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, bool
}
t << endl;
// For more specific builds, targets are in this form: build-platform, e.g. release-armv6
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": $(ABLD)" << endl;
t << "\t$(ABLD)" << testClause << " build " << item << " udeb" << endl;
@@ -259,7 +259,7 @@ void SymbianAbldMakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, bool
}
t << endl;
- // For more specific builds, targets are in this form: build-platform, e.g. release-armv6
+ // For more specific builds, targets are in this form: build-platform, e.g. release-armv5
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": $(ABLD)" << endl;
diff --git a/qmake/generators/symbian/symmake_sbsv2.cpp b/qmake/generators/symbian/symmake_sbsv2.cpp
index bcb93af..cad2736 100644
--- a/qmake/generators/symbian/symmake_sbsv2.cpp
+++ b/qmake/generators/symbian/symmake_sbsv2.cpp
@@ -150,8 +150,8 @@ void SymbianSbsv2MakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, boo
t << "first: default" << endl;
if (debugPlatforms.contains("winscw"))
t << "default: debug-winscw";
- else if (debugPlatforms.contains("armv6"))
- t << "default: debug-armv6";
+ else if (debugPlatforms.contains("armv5"))
+ t << "default: debug-armv5";
else if (debugPlatforms.size())
t << "default: debug-" << debugPlatforms.first();
else
@@ -182,7 +182,7 @@ void SymbianSbsv2MakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, boo
}
t << endl;
// For more specific builds, targets are in this form: build-platform, e.g. release-armv6
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": " << BLD_INF_FILENAME << endl;
t << "\t$(SBS) -c " << item << "_udeb" << testClause << endl;
@@ -182,7 +182,7 @@ void SymbianSbsv2MakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, boo
}
t << endl;
- // For more specific builds, targets are in this form: build-platform, e.g. release-armv6
+ // For more specific builds, targets are in this form: build-platform, e.g. release-armv5
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": " << BLD_INF_FILENAME << endl;